function [T,d,f] = pagerank(A,p)
// Returns the vectors of indirect influences and indirect dependences and the matrix of indirect influences according with the PageRank method.
//
// Calling Sequence
//  pagerank(D,p) // Show the vector of indirect influences, always needs the parameters D and p.
//  [T,d,f]=pagerank(D,p) // Show the vector of indirect influences f, the vector of indirect dependences d and the matrix T of indirect influences.
//
// Parameters
// p: Value of the parameter for the PageRank method, look the bibliography.
// D: Transpose of the adjacency matrix of a graph.
// f: Name of the variable to store the indirect influences vector.
// d: Name of the variable to store the indirect dependences vector.
// T: Name of the variable to store the indirect influences matrix.
//
// Description
// This function gives the vector of indirect influences and dependences and the matrix of indirect influences of a given matrix of direct influences according with the PageRank method. You only need to declare the adjacency matrix of the graph, the function makes all the process. This function does'nt support polynomial matrices.
//
// Examples
// D = [1 0 1;0 0 0;0 0 6] // Define the transpose of the adjacency matrix of a graph.
// [T,d,f] = pagerank(D,0.86)  // Returns the matrix of indirect influences T, the vector of indirect dependences d and the vector of indirect influences f.
// [T,d,f] = micmac(D,0.95)  // The same as above but with p equal to 0.95.
//
// See also
//  influence
//  dependence
//  normal
//  micmac
//  pagerank
//  pwp
//  heatkernel
//
// Authors
//  Jorge Catumba ;
// Bibliography
//   Indirect Influences, Rafael Díaz. preprint http://arxiv.org/abs/0906.1610v1
//   Cálculo de Influencias Indirectas en Scilab. Rafael Díaz, Jorge Catumba.

  j=size(A,"c")

  if (typeof(A)=='polynomial') then
   error('El metodo PageRank no puede usarse en una matriz polinomial') 
  else
    for var=1:j
      out(1,var)=sum(A(:,var))
    end

    for fil=1:j
      for col=1:j
        if (A(fil,col)~=0) then
          D(fil,col)=1/out(1,col)*A(fil,col)
        else
          D(fil,col)=0
        end
      end
    end

    cero=zeros(j,j)
    verdad=and(D==cero,"r")

    for ind=1:j
      if (verdad(1,ind)==%T) then
        Dbar(1:j,ind)=1/j
      else
        Dbar(1:j,ind)=D(1:j,ind)
      end
    end

    En=normal(j)

    T=(p*Dbar+(1-p)*En)^20
    d=dependence(T)*(1/j)
    f=influence(T)
  end

endfunction