function [T,d,f]=pwp(D,lambda)
// Returns the vectors of indirect influences and indirect dependences and the matrix of indirect influences according with the PWP method.
//
// Calling Sequence
//  pwp(D,lambda) // Show the vector of indirect influences, always needs the parameters D and lambda.
//  [T,d,f]=pwp(D,lambda) // Show the vector of indirect influences f, the vector of indirect dependences d and the matrix T of indirect influences.
//
// Parameters
// lambda: Value of the parameter for the PWP method, look the bibliography.
// D: Matrix of direct influences.
// f: Name of the variable to store the indirect influences vector.
// d: Name of the variable to store the indirect dependences vector.
// T: Name of the variable to store the indirect influences matrix.
//
// Description
// This function gives the vector of indirect influences and dependences and the matrix of indirect influences of a given matrix of direct influences according with the PWP method.
// If the matrix of direct influences has polynomial entries the function asks for a time parameter. For more info look the bibliography.
//
// Examples
// D = [1 0 1;0 0 0;0 0 6] // Define the matrix of direct influences.
// [T,d,f] = pwp(D,1)  // Returns the matrix of indirect influences T, the vector of indirect dependences d and the vector of indirect influences f.
// [T,d,f] = micmac(D,0.9)  // The same as above but with lambda equal to 0.9.
// t=poly(0,'t')  // Define the variable t.
// D = [t 1-t;t^2 1] // Define a 2x2 matrix with polynomial entries.
// [T,d,f] = pwp(D,1) // Apply the PWP method to matrix D, the function ask for a time parameter.
//
// See also
//  influence
//  dependence
//  micmac
//  pagerank
//  pwp
//  heatkernel
//
// Authors
//  Jorge Catumba ;
// Bibliography
//   Indirect Influences, Rafael Díaz. preprint http://arxiv.org/abs/0906.1610v1
//   Cálculo de Influencias Indirectas en Scilab. Rafael Díaz, Jorge Catumba.

  j=size(D,"r")

  if (typeof(D)=='polynomial') then
    T1=(polyexpm(lambda*D)-eye(j,j))/(exp(lambda)-1)
    C=coeff(T1)
    n=size(T1,"c")
		m=size(C,"c")
		time=input("Introduzca el tiempo ")
		if (time > m/n-1) then
			error('El valor de tiempo es muy alto')
		else
    	    T=C(:,time*n+1:(time+1)*n)
		end
  else
    T=(expm(lambda*D)-eye(j,j))/(exp(lambda)-1)
  end
  
  vectord=dependence(T)
  suma=sum(vectord)
  if (suma~=0)
    d=vectord/suma
  else
    d=vectord
  end
  vectorf=influence(T)
  suma=sum(vectorf)
  if (suma~=0)
    f=vectorf/suma
  else
    f=vectorf
  end
endfunction